@@ -2,8 +2,9 @@
 .. moduleauthor:: Erwin Lejeune
 """
 
-__version__ = '1.0.1'
+__version__ = '1.0.3'
 
+from nexo.async_client import AsyncClient
 from nexo.client import Client
 from nexo.response_serializers import (
     AdvancedOrderResponse,
@@ -20,5 +21,5 @@ from nexo.exceptions import (
     NexoAPIException,
     NotImplementedException,
     NexoRequestException,
-    NEXO_API_ERROR_CODES
+    NEXO_API_ERROR_CODES,
 )
